summaryrefslogtreecommitdiffstats
path: root/kdat/Archive.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:15 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:15 -0600
commit377fa3a2775cdb3194315bb83e21744dc7c97bbf (patch)
treeb6f515484589d67271adb168a1ead39f1c98493d /kdat/Archive.h
parentd1248617107f659af9d03cf1ef6d783571a0cba8 (diff)
downloadtdeadmin-377fa3a2775cdb3194315bb83e21744dc7c97bbf.tar.gz
tdeadmin-377fa3a2775cdb3194315bb83e21744dc7c97bbf.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit d1248617107f659af9d03cf1ef6d783571a0cba8.
Diffstat (limited to 'kdat/Archive.h')
-rw-r--r--kdat/Archive.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kdat/Archive.h b/kdat/Archive.h
index 9f42684..7527073 100644
--- a/kdat/Archive.h
+++ b/kdat/Archive.h
@@ -39,7 +39,7 @@ class Archive {
FILE* _fptr;
int _offset;
TQString _name;
- TQPtrList<File> _children;
+ TQPtrList<File> _tqchildren;
RangeList _ranges;
Tape* _tape;
public:
@@ -67,7 +67,7 @@ public:
Archive( Tape* tape, FILE* fptr, int offset );
/**
* Destroy the archive entry and all of its children.
*/
~Archive();
@@ -82,7 +82,7 @@ public:
/**
* Recursively read the instance data for this archive entry and all of its
* children. This method is used when converting from an older index format.
*
* @param version The version of the old tape index.
*/
@@ -90,7 +90,7 @@ public:
/**
* Write out the archive entry to the open file. Entries for each of its
* children will also be written.
*/
void write( FILE* fptr );
@@ -125,12 +125,12 @@ public:
/**
* Get the list of top-level files in this archive.
*
* @return A list of the immediate children of this archive.
*/
const TQPtrList<File>& getChildren();
/**
* Get the list of ranges of this file and all of its children.
*
* @return A list of ranges.
*/
@@ -176,7 +176,7 @@ public:
File* addFile( int size, int mtime, int startRecord, int endRecord, const TQString & filename );
/**
* Recursively calculate the list of ranges for all of the archive's children.
*/
void calcRanges();
};
@@ -67,7 +67,7 @@ public:
Archive( Tape* tape, FILE* fptr, int offset );
/**
- * Destroy the archive entry and all of its children.
+ * Destroy the archive entry and all of its tqchildren.
*/
~Archive();
@@ -82,7 +82,7 @@ public:
/**
* Recursively read the instance data for this archive entry and all of its
- * children. This method is used when converting from an older index format.
+ * tqchildren. This method is used when converting from an older index format.
*
* @param version The version of the old tape index.
@@ -90,7 +90,7 @@ public:
/**
* Write out the archive entry to the open file. Entries for each of its
- * children will also be written.
+ * tqchildren will also be written.
*/
void write( FILE* fptr );
@@ -125,12 +125,12 @@ public:
* Get the list of top-level files in this archive.
*
- * @return A list of the immediate children of this archive.
+ * @return A list of the immediate tqchildren of this archive.
*/
const TQPtrList<File>& getChildren();
@@ -125,12 +125,12 @@ public:
const TQPtrList<File>& getChildren();
/**
- * Get the list of ranges of this file and all of its children.
+ * Get the list of ranges of this file and all of its tqchildren.
*
* @return A list of ranges.
@@ -176,7 +176,7 @@ public:
File* addFile( int size, int mtime, int startRecord, int endRecord, const TQString & filename );
/**
- * Recursively calculate the list of ranges for all of the archive's children.
+ * Recursively calculate the list of ranges for all of the archive's tqchildren.
*/
void calcRanges();